PipeDecision

Enum PipeDecision 

pub enum PipeDecision {
    Allowed(PipeCommand),
    RequiresConfirmation(PipeCommand),
    Denied(PipeDeniedReason),
}
Policy decision for a :pipe command.

Variants



Allowed(PipeCommand)

The command is allowed because it used explicit confirmation.



RequiresConfirmation(PipeCommand)

The command is syntactically safe but needs explicit confirmation.



Denied(PipeDeniedReason)

The command is denied by policy.