pub fn export_section_markdown(
document: &IndexDocument,
selector: &str,
) -> Option<String>Expand description
Exports the first section whose heading or section title matches as Markdown.
pub fn export_section_markdown(
document: &IndexDocument,
selector: &str,
) -> Option<String>Exports the first section whose heading or section title matches as Markdown.